]> de.git.xonotic.org Git - xonotic/darkplaces.git/blobdiff - keys.c
sv_public now defaults to 0 except on dedicated servers
[xonotic/darkplaces.git] / keys.c
diff --git a/keys.c b/keys.c
index a98f5433b1df8963608f402bf5f706cf908ae581..804d7370b2060d830f5a2568b6e0798d7c56bd28 100644 (file)
--- a/keys.c
+++ b/keys.c
@@ -804,8 +804,8 @@ Key_Init (void)
        consolekeys[K_KP_MINUS] = true;
        consolekeys[K_KP_DIVIDE] = true;
        consolekeys[K_KP_MULTIPLY] = true;
-       consolekeys['`'] = true;
-       consolekeys['~'] = true;
+       consolekeys['`'] = false;
+       consolekeys['~'] = false;
 
        menubound[K_ESCAPE] = true;
        for (i = 0; i < 12; i++)
@@ -833,11 +833,10 @@ Should NOT be called during an interrupt!
 void
 Key_Event (int key, char ascii, qboolean down)
 {
-#if 1
+#if 0
 #define USERPLAYING()  ( !key_consoleactive && key_dest == key_game && (cls.state == ca_connected && cls.signon == SIGNONS) )
-//#define CONSOLEKEY() (key_consoleactive && !consolekeys[key])
-#define CONSOLEKEY()   ( key_dest == key_console)
        const char *bind;
+       static qboolean shift_down = false;
 
        // get key binding
        bind = keybindings[ key_bmap ][ key ];
@@ -859,8 +858,8 @@ Key_Event (int key, char ascii, qboolean down)
                key_repeats[ key ] = 0;
        }
 
-       if( key == K_CTRL ) {
-               ctrl_down = down;
+       if( key == K_SHIFT ) {
+               shift_down = down;
        }
 
        if( !down ) {
@@ -870,8 +869,8 @@ Key_Event (int key, char ascii, qboolean down)
        } else {
                // handle ESCAPE specially, so unbinding wont help
                if( key == K_ESCAPE ) {
-                       // ctrl-escape is a safety measure for users who cant toggle the console otherwise
-                       if( ctrl_down ) {
+                       // shift-escape is a safety measure for users who cant toggle the console otherwise
+                       if( shift_down ) {
                                Con_ToggleConsole_f();
                                return;
                        }
@@ -891,8 +890,7 @@ Key_Event (int key, char ascii, qboolean down)
                        return;
                }
 
-               if (bind && !strncmp( bind, "toggleconsole", strlen( "toggleconsole" ) ) )
-               {
+               if( !(key_consoleactive && consolekeys[ key ]) && bind && !strncmp( bind, "toggleconsole", strlen( "toggleconsole" ) ) ) {
                        Cbuf_AddText( bind );
                        Cbuf_AddText( "\n" );
                } else {
@@ -905,7 +903,7 @@ Key_Event (int key, char ascii, qboolean down)
                        // menu bind/function keys or normal binds
                        if( (key_dest == key_menu && menubound[key]) || USERPLAYING() ) {
                                if( bind ) {
-                                       if( bind[0] == '+' ) {                  // button commands add keynum as a parm
+                                       if( bind[0] == '+' ) { // button commands add keynum as a parm
                                                Cbuf_AddText( va( "%s %i\n", bind, key ) );
                                        } else {
                                                Cbuf_AddText( bind );
@@ -927,7 +925,7 @@ Key_Event (int key, char ascii, qboolean down)
                                case key_menu:
                                        MR_Keydown( key, ascii );
                                        break;
-                               case key_game:
+                               case key_game:                          
                                        // unbound key
                                        break;
                                default: